mod color;
mod config;
mod event;
mod radialbuilder;
mod radialelement;
mod rect;
mod sceneaction;
mod spritebuilder;
mod spriteelement;
mod state;
mod textboxbuilder;
mod util;

pub use color::*;
pub use config::*;
pub use event::*;
pub use radialbuilder::*;
pub use radialelement::*;
pub use rect::*;
pub use sceneaction::*;
pub use spritebuilder::*;
pub use spriteelement::*;
pub use state::*;
pub use textboxbuilder::*;
pub use util::*;

use rhai::{exported_module, Engine};

pub fn register_into_engine(engine: &mut Engine) {
	engine
		// Helpers
		.build_type::<Rect>()
		.build_type::<Color>()
		.build_type::<SceneConfig>()
		// State
		.build_type::<State>()
		.build_type::<ShipState>()
		.build_type::<SystemObjectState>()
		// Builders
		.build_type::<RadialBuilder>()
		.build_type::<SpriteBuilder>()
		.build_type::<TextBoxBuilder>()
		// Elements
		.build_type::<SpriteElement>()
		.build_type::<RadialElement>()
		// Events
		.build_type::<MouseClickEvent>()
		.build_type::<MouseHoverEvent>()
		.build_type::<PlayerShipStateEvent>()
		// Larger modules
		.register_type_with_name::<SpriteAnchor>("SpriteAnchor")
		.register_static_module("SpriteAnchor", exported_module!(spriteanchor_mod).into())
		.register_type_with_name::<SceneAction>("SceneAction")
		.register_static_module("SceneAction", exported_module!(sceneaction_mod).into());
}
